summaryrefslogtreecommitdiffstats
path: root/unix
diff options
context:
space:
mode:
authorfvogel <fvogelnew1@free.fr>2020-01-28 20:50:42 (GMT)
committerfvogel <fvogelnew1@free.fr>2020-01-28 20:50:42 (GMT)
commitc505cb05e89e61c208b36a80490702463cad8c94 (patch)
treead3ef3026c1944e4fb3296400f42ed7dae7177bb /unix
parent76c716ec23df52b6a2a38e95bae731c9845c2a1e (diff)
downloadtk-c505cb05e89e61c208b36a80490702463cad8c94.zip
tk-c505cb05e89e61c208b36a80490702463cad8c94.tar.gz
tk-c505cb05e89e61c208b36a80490702463cad8c94.tar.bz2
Restore %A for KeyRelease on Linux
Diffstat (limited to 'unix')
-rw-r--r--unix/tkUnixKey.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/unix/tkUnixKey.c b/unix/tkUnixKey.c
index 1bfbf26..003b090 100644
--- a/unix/tkUnixKey.c
+++ b/unix/tkUnixKey.c
@@ -126,11 +126,11 @@ TkpGetString(
}
/*
* Only do this for KeyPress events, otherwise
* further Xlib function behavior might be undefined.
*/
- if (eventPtr->type != KeyPress) {
+ if (event.type != KeyPress && event.type != KeyRelease)) {
len = 0;
Tcl_DStringSetLength(dsPtr, len);
goto done;
@@ -126,11 +126,11 @@ TkpGetString(
}
/*
- * Only do this for KeyPress events, otherwise
+ * Only do this for KeyPress and KeyRelease events, otherwise
* further Xlib function behavior might be undefined.
*/